@@ -2,7 +2,7 @@
 |''Name''|TiddlyWebConfig|
 |''Description''|configuration settings for TiddlyWebWiki|
 |''Author''|FND|
-|''Version''|1.2.0|
+|''Version''|1.2.1|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/plugins/TiddlyWebConfig.js|
 |''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
@@ -46,6 +46,21 @@ var plugin = config.extensions.tiddlyweb = {
 		} else {
 			return true;
 		}
+	},
+	// NB: pseudo-binaries are considered non-binary here
+	isBinary: function(tiddler) {
+		var type = tiddler.fields["server.content-type"];
+		if(type) {
+			var pseudoBinary = type.indexOf("text/") == 0 ||
+				this.endsWith(type, "+xml");
+			return !pseudoBinary;
+		} else {
+			return false;
+		}
+	},
+	endsWith: function(str, suffix) {
+		return str.length >= suffix.length &&
+			str.substr(str.length - suffix.length) == suffix;
 	}
 };
 
@@ -65,7 +80,7 @@ config.commands.saveTiddler.isEnabled = function(tiddler) {
 };
 
 config.commands.deleteTiddler.isEnabled = function(tiddler) {
-	return plugin.hasPermission("delete", tiddler) && !tiddler.isReadOnly();
+	return !readOnly && plugin.hasPermission("delete", tiddler);
 };
 
 // hijack option macro to disable username editing
@@ -87,10 +102,8 @@ config.macros.option.handler = function(place, macroName, params, wikifier, para
 // hijack isReadOnly to take into account permissions and content type
 var _isReadOnly = Tiddler.prototype.isReadOnly;
 Tiddler.prototype.isReadOnly = function() {
-	var readOnly = _isReadOnly.apply(this, arguments); // global read-only mode
-	var type = this.fields["server.content-type"];
-	var binary = type ? type.indexOf("text/") != 0 : false;
-	return readOnly || binary || !plugin.hasPermission("write", this);
+	return _isReadOnly.apply(this, arguments) || plugin.isBinary(this) ||
+		!plugin.hasPermission("write", this);
 };
 
 var getStatus = function(callback) {
